@@ -87,8 +87,6 @@ if 'def_queue' not in tmpSelf.__dict__:
     tmpSelf.__dict__['def_queue'] = 'ANALY_BNL_ATLAS_1'
 if 'def_nickname' not in tmpSelf.__dict__:
     tmpSelf.__dict__['def_nickname'] = 'BNL_ATLAS_1-condor'
-if 'def_dq2url' not in tmpSelf.__dict__:
-    tmpSelf.__dict__['def_dq2url'] = 'http://dms02.usatlas.bnl.gov:8000/dq2/'
 if 'def_ddm' not in tmpSelf.__dict__:
     tmpSelf.__dict__['def_ddm'] = 'PANDA_UNDEFINED2'
 if 'def_type' not in tmpSelf.__dict__:
