@@ -2,6 +2,8 @@ import requests
 import time
 import os
 
+from pandaserver.config import panda_config
+
 GB = 1024**3
 PROD_INPUT = 'Production Input'
 PROD_OUTPUT = 'Production Output'
@@ -25,13 +27,17 @@ def get_dump(url):
     """
     Retrieves a json file from the given URL and loads it into memory
     """
-    key_file = os.environ['X509_USER_PROXY']
-    cert_file = os.environ['X509_USER_PROXY']
-    ca_certs = os.environ['X509_CERT_DIR']
-
+    if panda_config.configurator_use_cert:
+        key_file = os.environ['X509_USER_PROXY']
+        cert_file = os.environ['X509_USER_PROXY']
+        ca_certs = os.environ['X509_CERT_DIR']
+        cert = (cert_file, key_file)
+    else:
+        cert = None
+        ca_certs = False
     for i in range(1, 4):  # 3 retries
         try:
-            r = requests.get(url, cert=(cert_file, key_file), verify=ca_certs)
+            r = requests.get(url, cert=cert, verify=ca_certs)
             if r.status_code == requests.codes.ok:
                 return r.json()
         except Exception:
