@@ -13,7 +13,7 @@ import traceback
 import pandaserver.jobdispatcher.Protocol as Protocol
 import pandaserver.taskbuffer.ProcessGroups
 from pandaserver.taskbuffer.WrappedPickle import WrappedPickle
-from pandaserver.srvcore.CoreUtils import clean_user_id
+from pandaserver.srvcore.CoreUtils import clean_user_id, resolve_bool
 from pandaserver.brokerage.SiteMapper import SiteMapper
 from pandaserver.taskbuffer import PrioUtil, JobUtils
 from pandaserver.dataservice.DDM import rucioAPI
@@ -1119,7 +1119,6 @@ def _getWGwithPR(req):
     return None
 
 
-
 """
 web service interface
 
@@ -1247,7 +1246,10 @@ def insertSandboxFileInfo(req,userName,fileName,fileSize,checkSum):
     if not prodManager:
         return "ERROR: missing role"
     # hostname
-    hostName = req.get_remote_host()
+    if hasattr(panda_config, 'sandboxHostname') and panda_config.sandboxHostname:
+        hostName = panda_config.sandboxHostname
+    else:
+        hostName = req.get_remote_host()
     # exec
     return userIF.insertSandboxFileInfo(userName,hostName,fileName,fileSize,checkSum)
 
@@ -2583,7 +2585,8 @@ def relay_idds_command(req, command_name, args=None, kwargs=None, manager=None):
         tmpLog.error(tmpStr)
         return json.dumps((False, tmpStr))
     try:
-        if manager is not True:
+        manager = resolve_bool(manager)
+        if not manager:
             manager = False
         if '+' in command_name:
             command_name, idds_host = command_name.split('+')
